changeset 44227:a1c4f9151348

(tcl-imenu-create-index-function): Doc fix.
author Richard M. Stallman <rms@gnu.org>
date Fri, 29 Mar 2002 12:47:57 +0000
parents 807078ed0771
children 8dcac1c05e8e
files lisp/progmodes/tcl.el
diffstat 1 files changed, 4 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/progmodes/tcl.el	Fri Mar 29 12:46:02 2002 +0000
+++ b/lisp/progmodes/tcl.el	Fri Mar 29 12:47:57 2002 +0000
@@ -6,7 +6,7 @@
 ;; Author: Tom Tromey <tromey@redhat.com>
 ;;    Chris Lindblad <cjl@lcs.mit.edu>
 ;; Keywords: languages tcl modes
-;; Version: $Revision: 1.65 $
+;; Version: $Revision: 1.66 $
 
 ;; This file is part of GNU Emacs.
 
@@ -76,7 +76,7 @@
 ;;   middle of a defun, or between defuns.  should notice if point is
 ;;   on first line of defun (or maybe even in comments before defun).
 ;; * Allow continuation lines to be indented under the first argument
 ;;   of the preceeding line, like this:
 ;;      [list something \
 ;;            something-else]
 ;; * There is a request that indentation work like this:
@@ -988,7 +988,7 @@
 ;;
 
 (defun tcl-imenu-create-index-function ()
-  "Generate alist of indices for imenu."
+  "Generate alist of indices for `imenu'."
   (let ((re (concat tcl-proc-regexp "\\([^ \t\n{]+\\)"))
 	alist prev-pos)
     (goto-char (point-min))
@@ -1189,7 +1189,7 @@
   "Return t if point is just after the `#' beginning a real comment.
 Does not check to see if previous char is actually `#'.
 A real comment is either at the beginning of the buffer,
-preceeded only by whitespace on the line, or has a preceeding
+preceded only by whitespace on the line, or has a preceding
 semicolon, opening brace, or opening bracket on the same line."
   (save-excursion
     (backward-char)
@@ -76,7 +76,7 @@
 ;;   on first line of defun (or maybe even in comments before defun).
 ;; * Allow continuation lines to be indented under the first argument
-;;   of the preceeding line, like this:
+;;   of the preceding line, like this:
 ;;      [list something \
 ;;            something-else]